Method: Plotrb::Kernel.data
- Defined in:
- lib/plotrb/kernel.rb
.data ⇒ Object
a global space keeping track of all Data objects defined
7 8 9 |
# File 'lib/plotrb/kernel.rb', line 7 def self.data @data ||= [] end |
a global space keeping track of all Data objects defined
7 8 9 |
# File 'lib/plotrb/kernel.rb', line 7 def self.data @data ||= [] end |